Module array_vec

Module array_vec 

Stack-allocated vector types with sentinel-based and length-based variants.

Modules

invalid_value

Structs

ArchivedArrayVec
An archived ArrayVec
ArrayVec
Fixed-capacity vector backed by an array, using a sentinel value to mark empty slots.
ArrayVecConstructionError
Error returned when constructing an array-backed vector with too many elements.
ArrayVecResolver
The resolver for an archived ArrayVec
ArrayVecWithLen
Fixed-capacity vector backed by an array, with an explicit length field.
PackedU8Vec
A compact byte vector that packs up to 4 bytes into a single u32.
PtrIter
Iterator over references to valid elements in an ArrayVec.