Stack-allocated vector types with sentinel-based and length-based variants.
Modules
Structs
- Archived
Array Vec - An archived
ArrayVec - Array
Vec - Fixed-capacity vector backed by an array, using a sentinel value to mark empty slots.
- Array
VecConstruction Error - Error returned when constructing an array-backed vector with too many elements.
- Array
VecResolver - The resolver for an archived
ArrayVec - Array
VecWith Len - Fixed-capacity vector backed by an array, with an explicit length field.
- Packed
U8Vec - A compact byte vector that packs up to 4 bytes into a single
u32. - PtrIter
- Iterator over references to valid elements in an
ArrayVec.